@@ -4,9 +4,13 @@
 //!
 //! ```text
 //! [dependencies]
-//! eint = "0.1.2"
+//! eint = "0.1"
 //! ```
 
+#![no_std]
+extern crate alloc;
+use alloc::{format, string::String};
+
 pub trait Eint:
     Clone
     + Copy
@@ -25,31 +29,31 @@ pub trait Eint:
     + From<u128>
     + From<Self>
     + PartialEq
-    + std::cmp::Ord
-    + std::cmp::PartialOrd
-    + std::fmt::Debug
-    + std::fmt::Display
-    + std::fmt::LowerHex
-    + std::ops::Add<Output = Self>
-    + std::ops::AddAssign
-    + std::ops::BitAnd<Output = Self>
-    + std::ops::BitAndAssign
-    + std::ops::BitOr<Output = Self>
-    + std::ops::BitOrAssign
-    + std::ops::BitXor<Output = Self>
-    + std::ops::BitXorAssign
-    + std::ops::Div<Output = Self>
-    + std::ops::DivAssign
-    + std::ops::Mul<Output = Self>
-    + std::ops::MulAssign
-    + std::ops::Neg<Output = Self>
-    + std::ops::Not
-    + std::ops::Rem<Output = Self>
-    + std::ops::RemAssign
-    + std::ops::Sub<Output = Self>
-    + std::ops::SubAssign
-    + std::ops::Shl<u32, Output = Self>
-    + std::ops::Shr<u32, Output = Self>
+    + core::cmp::Ord
+    + core::cmp::PartialOrd
+    + core::fmt::Debug
+    + core::fmt::Display
+    + core::fmt::LowerHex
+    + core::ops::Add<Output = Self>
+    + core::ops::AddAssign
+    + core::ops::BitAnd<Output = Self>
+    + core::ops::BitAndAssign
+    + core::ops::BitOr<Output = Self>
+    + core::ops::BitOrAssign
+    + core::ops::BitXor<Output = Self>
+    + core::ops::BitXorAssign
+    + core::ops::Div<Output = Self>
+    + core::ops::DivAssign
+    + core::ops::Mul<Output = Self>
+    + core::ops::MulAssign
+    + core::ops::Neg<Output = Self>
+    + core::ops::Not
+    + core::ops::Rem<Output = Self>
+    + core::ops::RemAssign
+    + core::ops::Sub<Output = Self>
+    + core::ops::SubAssign
+    + core::ops::Shl<u32, Output = Self>
+    + core::ops::Shr<u32, Output = Self>
 {
     const BITS: u32;
     const MAX_S: Self;
@@ -101,10 +105,10 @@ pub trait Eint:
     fn clz(self) -> u32;
 
     /// Compare signed.
-    fn cmp_s(&self, other: &Self) -> std::cmp::Ordering;
+    fn cmp_s(&self, other: &Self) -> core::cmp::Ordering;
 
     /// Compare.
-    fn cmp_u(&self, other: &Self) -> std::cmp::Ordering;
+    fn cmp_u(&self, other: &Self) -> core::cmp::Ordering;
 
     /// Returns the number of ones in the binary representation of self.
     fn cpop(self) -> u32;
@@ -332,7 +336,7 @@ pub trait Eint:
 #[macro_export]
 macro_rules! construct_eint_wrap_from_uint {
     ($name:ident, $uint:ty, $from:ty) => {
-        impl std::convert::From<$from> for $name {
+        impl core::convert::From<$from> for $name {
             fn from(small: $from) -> Self {
                 Self(small as $uint)
             }
@@ -358,20 +362,20 @@ macro_rules! construct_eint_wrap {
         construct_eint_wrap_from_uint!($name, $uint, u64);
         construct_eint_wrap_from_uint!($name, $uint, u128);
 
-        impl std::cmp::Ord for $name {
-            fn cmp(&self, other: &Self) -> std::cmp::Ordering {
+        impl core::cmp::Ord for $name {
+            fn cmp(&self, other: &Self) -> core::cmp::Ordering {
                 self.0.cmp(&other.0)
             }
         }
 
-        impl std::cmp::PartialOrd for $name {
-            fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+        impl core::cmp::PartialOrd for $name {
+            fn partial_cmp(&self, other: &Self) -> Option<core::cmp::Ordering> {
                 return self.0.partial_cmp(&other.0);
             }
         }
 
-        impl std::fmt::Debug for $name {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        impl core::fmt::Debug for $name {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 let suffix = format!("{:x}", self.0);
                 let prefix = String::from("0").repeat(Self::BITS as usize / 4 - suffix.len());
                 write!(f, "{}", prefix)?;
@@ -379,8 +383,8 @@ macro_rules! construct_eint_wrap {
             }
         }
 
-        impl std::fmt::Display for $name {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        impl core::fmt::Display for $name {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 let suffix = format!("{:x}", self.0);
                 let prefix = String::from("0").repeat(Self::BITS as usize / 4 - suffix.len());
                 write!(f, "{}", prefix)?;
@@ -388,8 +392,8 @@ macro_rules! construct_eint_wrap {
             }
         }
 
-        impl std::fmt::LowerHex for $name {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        impl core::fmt::LowerHex for $name {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 let suffix = format!("{:x}", self.0);
                 let prefix = String::from("0").repeat(Self::BITS as usize / 4 - suffix.len());
                 write!(f, "{}", prefix)?;
@@ -397,20 +401,20 @@ macro_rules! construct_eint_wrap {
             }
         }
 
-        impl std::ops::Add for $name {
+        impl core::ops::Add for $name {
             type Output = Self;
             fn add(self, other: Self) -> Self {
                 Self(self.0.wrapping_add(other.0))
             }
         }
 
-        impl std::ops::AddAssign for $name {
+        impl core::ops::AddAssign for $name {
             fn add_assign(&mut self, other: Self) {
                 self.0 = self.0.wrapping_add(other.0)
             }
         }
 
-        impl std::ops::Div for $name {
+        impl core::ops::Div for $name {
             type Output = Self;
             fn div(self, other: Self) -> Self::Output {
                 if other.0 == 0 {
@@ -421,7 +425,7 @@ macro_rules! construct_eint_wrap {
             }
         }
 
-        impl std::ops::DivAssign for $name {
+        impl core::ops::DivAssign for $name {
             fn div_assign(&mut self, other: Self) {
                 self.0 = if other.0 == 0 {
                     <$uint>::MAX
@@ -431,73 +435,73 @@ macro_rules! construct_eint_wrap {
             }
         }
 
-        impl std::ops::BitAnd for $name {
+        impl core::ops::BitAnd for $name {
             type Output = Self;
             fn bitand(self, other: Self) -> Self::Output {
                 Self(self.0 & other.0)
             }
         }
 
-        impl std::ops::BitAndAssign for $name {
+        impl core::ops::BitAndAssign for $name {
             fn bitand_assign(&mut self, other: Self) {
                 self.0 &= other.0
             }
         }
 
-        impl std::ops::BitOr for $name {
+        impl core::ops::BitOr for $name {
             type Output = Self;
             fn bitor(self, other: Self) -> Self::Output {
                 Self(self.0 | other.0)
             }
         }
 
-        impl std::ops::BitOrAssign for $name {
+        impl core::ops::BitOrAssign for $name {
             fn bitor_assign(&mut self, other: Self) {
                 self.0 |= other.0
             }
         }
 
-        impl std::ops::BitXor for $name {
+        impl core::ops::BitXor for $name {
             type Output = Self;
             fn bitxor(self, other: Self) -> Self::Output {
                 Self(self.0 ^ other.0)
             }
         }
 
-        impl std::ops::BitXorAssign for $name {
+        impl core::ops::BitXorAssign for $name {
             fn bitxor_assign(&mut self, other: Self) {
                 self.0 ^= other.0
             }
         }
 
-        impl std::ops::Mul for $name {
+        impl core::ops::Mul for $name {
             type Output = Self;
             fn mul(self, other: Self) -> Self::Output {
                 Self(self.0.wrapping_mul(other.0))
             }
         }
 
-        impl std::ops::MulAssign for $name {
+        impl core::ops::MulAssign for $name {
             fn mul_assign(&mut self, other: Self) {
                 self.0 = self.0.wrapping_mul(other.0)
             }
         }
 
-        impl std::ops::Neg for $name {
+        impl core::ops::Neg for $name {
             type Output = Self;
             fn neg(self) -> Self::Output {
                 Self((!self.0).wrapping_add(1))
             }
         }
 
-        impl std::ops::Not for $name {
+        impl core::ops::Not for $name {
             type Output = Self;
             fn not(self) -> Self::Output {
                 Self(!self.0)
             }
         }
 
-        impl std::ops::Rem for $name {
+        impl core::ops::Rem for $name {
             type Output = Self;
             fn rem(self, other: Self) -> Self::Output {
                 if other.0 == 0 {
@@ -508,7 +512,7 @@ macro_rules! construct_eint_wrap {
             }
         }
 
-        impl std::ops::RemAssign for $name {
+        impl core::ops::RemAssign for $name {
             fn rem_assign(&mut self, other: Self) {
                 self.0 = if other.0 == 0 {
                     self.0
@@ -518,28 +522,28 @@ macro_rules! construct_eint_wrap {
             }
         }
 
-        impl std::ops::Shl<u32> for $name {
+        impl core::ops::Shl<u32> for $name {
             type Output = Self;
             fn shl(self, other: u32) -> Self::Output {
                 Self(self.0.wrapping_shl(other))
             }
         }
 
-        impl std::ops::Shr<u32> for $name {
+        impl core::ops::Shr<u32> for $name {
             type Output = Self;
             fn shr(self, other: u32) -> Self::Output {
                 Self(self.0.wrapping_shr(other))
             }
         }
 
-        impl std::ops::Sub for $name {
+        impl core::ops::Sub for $name {
             type Output = Self;
             fn sub(self, other: Self) -> Self::Output {
                 Self(self.0.wrapping_sub(other.0))
             }
         }
 
-        impl std::ops::SubAssign for $name {
+        impl core::ops::SubAssign for $name {
             fn sub_assign(&mut self, other: Self) {
                 self.0 = self.0.wrapping_sub(other.0)
             }
@@ -570,11 +574,11 @@ macro_rules! construct_eint_wrap {
                 self.0.leading_zeros()
             }
 
-            fn cmp_s(&self, other: &Self) -> std::cmp::Ordering {
+            fn cmp_s(&self, other: &Self) -> core::cmp::Ordering {
                 (self.0 as $sint).cmp(&(other.0 as $sint))
             }
 
-            fn cmp_u(&self, other: &Self) -> std::cmp::Ordering {
+            fn cmp_u(&self, other: &Self) -> core::cmp::Ordering {
                 self.0.cmp(&other.0)
             }
 
@@ -764,7 +768,7 @@ uint_wrap_from_impl!(E128, E64);
 #[macro_export]
 macro_rules! construct_eint_twin_from_uint {
     ($name:ident, $half:ty, $from:ty) => {
-        impl std::convert::From<$from> for $name {
+        impl core::convert::From<$from> for $name {
             fn from(small: $from) -> Self {
                 Self(<$half>::from(small), <$half>::MIN_U)
             }
@@ -775,7 +779,7 @@ macro_rules! construct_eint_twin_from_uint {
 #[macro_export]
 macro_rules! construct_eint_twin_from_sint {
     ($name:ident, $half:ty, $from:ty) => {
-        impl std::convert::From<$from> for $name {
+        impl core::convert::From<$from> for $name {
             fn from(small: $from) -> Self {
                 let lo = <$half>::from(small);
                 let hi = if small >= 0 {
@@ -807,166 +811,166 @@ macro_rules! construct_eint_twin {
         construct_eint_twin_from_uint!($name, $half, u64);
         construct_eint_twin_from_uint!($name, $half, u128);
 
-        impl std::cmp::PartialOrd for $name {
-            fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+        impl core::cmp::PartialOrd for $name {
+            fn partial_cmp(&self, other: &Self) -> Option<core::cmp::Ordering> {
                 Some(self.cmp(other))
             }
         }
 
-        impl std::cmp::Ord for $name {
-            fn cmp(&self, other: &Self) -> std::cmp::Ordering {
+        impl core::cmp::Ord for $name {
+            fn cmp(&self, other: &Self) -> core::cmp::Ordering {
                 self.cmp_u(other)
             }
         }
 
-        impl std::fmt::Debug for $name {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        impl core::fmt::Debug for $name {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 write!(f, "{:x}{:x}", self.1, self.0)
             }
         }
 
-        impl std::fmt::Display for $name {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        impl core::fmt::Display for $name {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 write!(f, "{:x}{:x}", self.1, self.0)
             }
         }
 
-        impl std::fmt::LowerHex for $name {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        impl core::fmt::LowerHex for $name {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 write!(f, "{:x}{:x}", self.1, self.0)
             }
         }
 
-        impl std::ops::Add for $name {
+        impl core::ops::Add for $name {
             type Output = Self;
             fn add(self, other: Self) -> Self {
                 self.wrapping_add(other)
             }
         }
 
-        impl std::ops::AddAssign for $name {
+        impl core::ops::AddAssign for $name {
             fn add_assign(&mut self, other: Self) {
                 *self = self.wrapping_add(other)
             }
         }
 
-        impl std::ops::BitAnd for $name {
+        impl core::ops::BitAnd for $name {
             type Output = Self;
             fn bitand(self, other: Self) -> Self::Output {
                 Self(self.0 & other.0, self.1 & other.1)
             }
         }
 
-        impl std::ops::BitAndAssign for $name {
+        impl core::ops::BitAndAssign for $name {
             fn bitand_assign(&mut self, other: Self) {
                 self.0 &= other.0;
                 self.1 &= other.1;
             }
         }
 
-        impl std::ops::BitOr for $name {
+        impl core::ops::BitOr for $name {
             type Output = Self;
             fn bitor(self, other: Self) -> Self::Output {
                 Self(self.0 | other.0, self.1 | other.1)
             }
         }
 
-        impl std::ops::BitOrAssign for $name {
+        impl core::ops::BitOrAssign for $name {
             fn bitor_assign(&mut self, other: Self) {
                 self.0 |= other.0;
                 self.1 |= other.1;
             }
         }
 
-        impl std::ops::BitXor for $name {
+        impl core::ops::BitXor for $name {
             type Output = Self;
             fn bitxor(self, other: Self) -> Self::Output {
                 Self(self.0 ^ other.0, self.1 ^ other.1)
             }
         }
 
-        impl std::ops::BitXorAssign for $name {
+        impl core::ops::BitXorAssign for $name {
             fn bitxor_assign(&mut self, other: Self) {
                 self.0 ^= other.0;
                 self.1 ^= other.1;
             }
         }
 
-        impl std::ops::Div for $name {
+        impl core::ops::Div for $name {
             type Output = Self;
             fn div(self, other: Self) -> Self::Output {
                 self.wrapping_div_u(other)
             }
         }
 
-        impl std::ops::DivAssign for $name {
+        impl core::ops::DivAssign for $name {
             fn div_assign(&mut self, other: Self) {
                 *self = self.wrapping_div_u(other)
             }
         }
 
-        impl std::ops::Mul for $name {
+        impl core::ops::Mul for $name {
             type Output = Self;
             fn mul(self, other: Self) -> Self::Output {
                 self.wrapping_mul(other)
             }
         }
 
-        impl std::ops::MulAssign for $name {
+        impl core::ops::MulAssign for $name {
             fn mul_assign(&mut self, other: Self) {
                 *self = self.wrapping_mul(other)
             }
         }
 
-        impl std::ops::Neg for $name {
+        impl core::ops::Neg for $name {
             type Output = Self;
             fn neg(self) -> Self::Output {
                 (!self).wrapping_add(<$name>::ONE)
             }
         }
 
-        impl std::ops::Not for $name {
+        impl core::ops::Not for $name {
             type Output = Self;
             fn not(self) -> Self::Output {
                 Self(!self.0, !self.1)
             }
         }
 
-        impl std::ops::Rem for $name {
+        impl core::ops::Rem for $name {
             type Output = Self;
             fn rem(self, other: Self) -> Self::Output {
                 self.wrapping_rem_u(other)
             }
         }
 
-        impl std::ops::RemAssign for $name {
+        impl core::ops::RemAssign for $name {
             fn rem_assign(&mut self, other: Self) {
                 *self = self.wrapping_rem_u(other);
             }
         }
 
-        impl std::ops::Shl<u32> for $name {
+        impl core::ops::Shl<u32> for $name {
             type Output = Self;
             fn shl(self, other: u32) -> Self::Output {
                 self.wrapping_shl(other)
             }
         }
 
-        impl std::ops::Shr<u32> for $name {
+        impl core::ops::Shr<u32> for $name {
             type Output = Self;
             fn shr(self, other: u32) -> Self::Output {
                 self.wrapping_shr(other)
             }
         }
 
-        impl std::ops::Sub for $name {
+        impl core::ops::Sub for $name {
             type Output = Self;
             fn sub(self, other: Self) -> Self::Output {
                 self.wrapping_sub(other)
             }
         }
 
-        impl std::ops::SubAssign for $name {
+        impl core::ops::SubAssign for $name {
             fn sub_assign(&mut self, other: Self) {
                 *self = self.wrapping_sub(other)
             }
@@ -1016,20 +1020,20 @@ macro_rules! construct_eint_twin {
                 }
             }
 
-            fn cmp_s(&self, other: &Self) -> std::cmp::Ordering {
+            fn cmp_s(&self, other: &Self) -> core::cmp::Ordering {
                 let l_sign = self.is_negative();
                 let r_sign = other.is_negative();
                 match (l_sign, r_sign) {
                     (false, false) => self.cmp(&other),
-                    (false, true) => std::cmp::Ordering::Greater,
-                    (true, false) => std::cmp::Ordering::Less,
+                    (false, true) => core::cmp::Ordering::Greater,
+                    (true, false) => core::cmp::Ordering::Less,
                     (true, true) => self.cmp(&other),
                 }
             }
 
-            fn cmp_u(&self, other: &Self) -> std::cmp::Ordering {
+            fn cmp_u(&self, other: &Self) -> core::cmp::Ordering {
                 let hi_cmp = self.1.cmp(&other.1);
-                if hi_cmp != std::cmp::Ordering::Equal {
+                if hi_cmp != core::cmp::Ordering::Equal {
                     hi_cmp
                 } else {
                     self.0.cmp(&other.0)
@@ -1370,7 +1374,7 @@ macro_rules! construct_eint_twin {
 
 macro_rules! uint_twin_from_impl {
     ($name:ident, $half:ty, $from:ty) => {
-        impl std::convert::From<$from> for $name {
+        impl core::convert::From<$from> for $name {
             fn from(small: $from) -> Self {
                 Self(<$half>::from(small), <$half>::MIN_U)
             }
